@@ -5,8 +5,7 @@ from glob import glob
 from pathlib import Path
 
 from numpy.random import default_rng
-from phylogenie import Tree, load_newick
-from phylogenie.utils import get_node_depths
+from phylogenie import Tree, get_node_depths, load_newick
 from tqdm import tqdm
 
 from bella_companion.simulations.scenarios import SCENARIOS, ScenarioType
@@ -22,8 +21,10 @@ def run_beast():
     for scenario_name, scenario in SCENARIOS.items():
         job_ids[scenario_name] = defaultdict(dict)
         data_dir = base_data_dir / scenario_name
-        inference_configs_dir = Path(os.environ["BELLA_BEAST_CONFIGS_DIR"]) / (
-            scenario_name.split("_")[0] if "_" in scenario_name else scenario_name
+        inference_configs_dir = (
+            Path(__file__).parent
+            / "beast_configs"
+            / (scenario_name.split("_")[0] if "_" in scenario_name else scenario_name)
         )
         log_dir = Path(os.environ["BELLA_SBATCH_LOG_DIR"]) / scenario_name
         for tree_file in tqdm(
@@ -66,6 +67,7 @@ def run_beast():
                         [
                             *base_command,
                             f'-D nodes="{" ".join(map(str, nodes))}"',
+                            f'-D layersRange="{",".join(map(str, range(len(nodes) + 1)))}"',
                             str(inference_configs_dir / "MLP.xml"),
                         ]
                     )
